Gemeinde Adressverwaltung GUI: Gemeinde-Namensbereichsreferenz

Gemeinde Adressverwaltung GUI

Klassen | Variablen
Gemeinde-Namensbereichsreferenz

## Klassen
class | Login
class | Main

## Variablen
| logger = logging.getLogger()
string | MAIL_WITH_BCC_MESSAGE
| login = Login()
| main = Main()

## Ausführliche Beschreibung

    Gemeinde.py - Gemeinde Adressverwaltung GUI

        Beachte
            Alle Einstellungen werden der besseren Lesbarkeit in Gemeinde_Def.configuration definiert.

## Variablen-Dokumentation

## ◆ MAIL_WITH_BCC_MESSAGE

string Gemeinde.MAIL_WITH_BCC_MESSAGE

Initialisierung:
1 = """Achtung:
2 Die Protokoll-Mail ist angekreuzt.
3 D.h. es wird in jeder einzelnen verschickten
4 eMail der Absender im Bcc eingefügt.
5 Das sorgt u.U. für sehr viele Mails beim
6 Absender.
7 Sicher so weiter?
8 """